@@ -17,3 +17,12 @@ test_that("knitr-engine works", {
 
   expect_equal(eng_extendr(options), "## hello world!\n")
 })
+
+
+test_that("Snapshot test of knitr-engine", {
+  input <- file.path("../data/test-knitr-engine-source-01.Rmd")
+  output <- withr::local_file("snapshot_knitr_test.md")
+
+  knitr::knit(input, output)
+  expect_snapshot(cat_file(output))
+})
